## Introduction
SensitiBot is a Python bot that detects data leaks on public repositories.

It was conceived as a project for the Software Engineering degree final project.

## Getting Started
Install sensitibot using pip. It is advisable to do this in a Python virtualenv without system packages:
```
$ pip install sensitibot
```

> **Note:** Other methods of installation can be found in the [installation instructions](https://github.com/TFG-SensitiBot/SensitiBot/wiki/Installation).


## Documentation
The documentation can be found at: [SensitiBot's Wiki](https://github.com/TFG-SensitiBot/SensitiBot/wiki)
